#!/bin/bash
#
# Filename: Admin_user_password_set_process.sh
#
# Process a password change request. This could be for the
# user that is logged in, or it could be for another user. We
# can only allow the latter if the current user is an Administrator
#
# Copyright Ben Tasker 2009
# Released under the GNU GPL V3
# See http://benscomputer.no-ip.org/LICENSE for details


# Global Config

# Output Content-type

echo Content-Type: text/html
echo

./BUGGER_config.sh imascript /tmp/BUGGER.auth_process.conf.$$

source /tmp/BUGGER.auth_process.conf.$$
rm -f /tmp/BUGGER.auth_process.conf.$$ 2> /dev/null


REQUEST_URI=$(</dev/stdin)



# Functions go here
error_page ()
{

/bin/cat << EOM
<html>
<head>
<title>BUGGER - Password Change - $ERROR_TITLE</title>
</head>
<body bgcolor="white">
<font color="black">
<!-- Please leave Copyright Notice Intact -->


<!-- Generated by the BUGGER Project Management System -->
<!-- Copyright Ben Tasker 2009 -->
<!-- Released under the GNU GPL V3 -->
<!-- See http://benscomputer.no-ip.org/LICENSE -->
<!-- Obtain BUGGER from http://benscomputer.no-ip.org/2009/Nov/213301112009.shtml -->


<!-- Thanks --> 
<center><b><u>BUGGER - Password Change - $ERROR_TITLE </b></u></center>
<br><br>
<a href="$NONSSLWEBSERVER/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br>
<hr>
<br>
<br>
$ERROR_TEXT1
$ERROR_TEXT2
$ERROR_TEXT3
<br><br><a href="$NONSSLWEBSERVER/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br>
<hr>
<br><br>
EOM

./BUGGER_generate_footer.sh

/bin/cat << EOM
<!-- Please leave Copyright Notice Intact -->


<!-- Generated by the BUGGER Project Management System -->
<!-- Copyright Ben Tasker 2009 -->
<!-- Released under the GNU GPL V3 -->
<!-- See http://benscomputer.no-ip.org/LICENSE -->
<!-- Obtain BUGGER from http://benscomputer.no-ip.org/2009/Nov/213301112009.shtml -->


<!-- Thanks --> 

</body>
</html>
EOM


exit_function

}

process_Change ()
{
# Deal with the technical side of the password change

# Verify that the supplied passwords match

NEWPASS1=$( echo "$REQUEST_URI" | sed -n 's/^.*NEWPASS1=\([^&]*\).*$/\1/p' )
NEWPASS2=$( echo "$REQUEST_URI" | sed -n 's/^.*NEWPASS2=\([^&]*\).*$/\1/p' )

if [ "$NEWPASS1" != "$NEWPASS2" ]
then
ERROR_TITLE="Error: Passwords Don't Match"
ERROR_TEXT1="The passwords you supplied do not match. Please "
ERROR_TEXT2="<a href=\"/BUGGER/passwd_upd.shtml\">try again</a>"
error_page

fi

# Passwords match. We can disregard one of them now
NEWPASS2=""

# Now we need to create our salts
# and log when the password was last changed


# Create an array of possible salt characters
CHARS=(a b c d e f g h i j k l m n o p q r s t u v w x y z A B C D E F G H I J K L M N O P Q R S T U V W X Y Z 1 2 3 4 5 6 7 8 9 0 )

# How many characters should Salt 1 be?

CHARLENGTH="5"

# Create the salt, once character at a time
while [ "$CHARLENGTH" -gt "0" ]
do

SALT=$( echo -n ${CHARS[ (( ${RANDOM} % ${#CHARS[@]} )) ]} )
echo -n $SALT >> /tmp/.Salt_gen.$$
CHARLENGTH=$(( $CHARLENGTH - 1 ))

done

# Grab the salt from the file
SALT1=$( cat /tmp/.Salt_gen.$$ )

#
# Same procedure for Salt 2
#


CHARLENGTH="1"

# Create the salt, once character at a time
while [ "$CHARLENGTH" -gt "0" ]
do

SALT=$( echo -n ${CHARS[ (( ${RANDOM} % ${#CHARS[@]} )) ]} )
echo -n $SALT >> /tmp/.Salt_gen1.$$
CHARLENGTH=$(( $CHARLENGTH - 1 ))

done

# Grab the salt from the file
SALT2=$( cat /tmp/.Salt_gen1.$$ )

#
# Salt 3 is purely numerical so we can use a BASH variable for that
#

SALT3=$(( $RANDOM ))


# Salt 4 is a single character
CHARLENGTH="1"

# Create the salt, once character at a time
while [ "$CHARLENGTH" -gt "0" ]
do

SALT=$( echo -n ${CHARS[ (( ${RANDOM} % ${#CHARS[@]} )) ]} )
echo -n $SALT >> /tmp/.Salt_gen2.$$
CHARLENGTH=$(( $CHARLENGTH - 1 ))

done

# Grab the salt from the file
SALT2=$( cat /tmp/.Salt_gen2.$$ )



# We've created our Salts
# Whats the current date and time (in seconds)

CHANGETIME=$( date +'%s' )


# Salt the password
echo -n "$NEWPASS1" | tr '!-~' 'P-~!-O' > /tmp/.BUGGER.Pass_compliance_check1.$$
sed s/"$SALT2"/"$SALT1"/g /tmp/.BUGGER.Pass_compliance_check1.$$ > /tmp/.BUGGER.Pass_compliance_check2.$$
STAGE1=$( cat /tmp/.BUGGER.Pass_compliance_check2.$$ )
echo -n "$STAGE1" > /tmp/.BUGGER.Pass_compliance_check1.$$
echo "$CHANGETIME" >> /tmp/.BUGGER.Pass_compliance_check1.$$

sed s/"$SALT4"/"$SALT3"/g /tmp/.BUGGER.Pass_compliance_check1.$$ > /tmp/.BUGGER.Pass_compliance_check2.$$

# Generate the HASH

md5sum /tmp/.BUGGER.Pass_compliance_check2.$$ > /tmp/.BUGGER.Pass_compliance_check1.$$

# Only interested in the Sum itself

awk -F\  '{print $1}' /tmp/.BUGGER.Pass_compliance_check1.$$ > /tmp/.BUGGER.Pass_compliance_check2.$$

# Load it into a variable

NEWHASH=$( cat /tmp/.BUGGER.Pass_compliance_check2.$$ )

NEWPASS1=""

# So we now have

# SALT1
# SALT2
# SALT3
# SALT4
# CHANGETIME
# NEWHASH
# USERFIELD



# Send the changes to the Database
commit_changes_func
}

commit_changes_func ()
{
# Propogate the new details to the Database

wget -q -O /tmp/.BUGGER.passwdchange.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?DBNAME=Bugs&TABLE=Passwd&METHOD=5&QCOL=1&QSTRING=$USERFIELD"

LINE_NO=$( cat /tmp/.BUGGER.passwdchange.$$ )

if [ "$LINE_NO" != "NORESULTS" ]
then
# A record already exists, we need to delete it

wget -q -O /tmp/.BUGGER.passwdchange.clear.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?DBNAME=Bugs&TABLE=Passwd&METHOD=9&LINENO=$LINE_NO"

fi


# Insert the record
wget -q -O /tmp/.BUGGER.passwdchange.insert.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?DBNAME=Bugs&TABLE=Passwd&METHOD=1&COL1=$USERFIELD&COL2=$NEWHASH&COL3=$CHANGETIME&COL4=$SALT1&COL5=$SALT2&COL6=$SALT3&COL7=$SALT4"

STATUS=$( cat /tmp/.BUGGER.passwdchange.insert.$$ )

if [ "$STATUS" != "SUCCESS" ]
then
ERROR_TITLE="An Error Occurred"
ERROR_TEXT1="Your request was not successful, an error occurred. The response from Claims_DB was <br><br>"
ERROR_TEXT2="$STATUS<br><br>"
fi

generate_html
}


exit_function ()
{

rm -f /tmp/.BUGGER.user_record.$USERFIELD.$$ 2> /dev/null
rm -f /tmp/.BUGGER.Pass_compliance_check*.$$ 2> /dev/null
rm -f /tmp/.Salt_gen*.$$ 2> /dev/null 
rm -f /tmp/.BUGGER.passwdchange.$$ 2> /dev/null
rm -f /tmp/.BUGGER.passwdchange.clear.$$ 2> /dev/null
rm -f /tmp/.BUGGER.passwdchange.insert.$$ 2> /dev/null

exit
}


check_supplied_password ()
{
# Check if the supplied 'Old' password is correct

wget -q -O "/tmp/.BUGGER.user_record.$USERFIELD.$$" "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?DBNAME=Bugs&TABLE=Passwd&METHOD=4&QCOL=1&QSTRING=$USERFIELD"

# Check whether the username actually existed

STATUS=$( cat "/tmp/.BUGGER.user_record.$USERFIELD.$$" )



if [ "$STATUS" == "NORESULTS" ]
then
# Invalid Username, throw an error
ERROR_TEXT="ERROR - Access Denied"
ERROR_TEXT1="The supplied username is not valid. Perhaps someone has just disabled you?"

error_page
fi


# If we hit this part the username was valid, now we need to process the password

# Firstly what's the valid hash?

VALIDPASS=$( cat "/tmp/.BUGGER.user_record.$USERFIELD.$$" | awk -F\, '{print $2}' | sed s/\"//g )

# Grab the Salts

SALT1=$( cat "/tmp/.BUGGER.user_record.$USERFIELD.$$" | awk -F\, '{print $4}' | sed s/\"//g )
SALT2=$( cat "/tmp/.BUGGER.user_record.$USERFIELD.$$" | awk -F\, '{print $5}' | sed s/\"//g )
SALT3=$( cat "/tmp/.BUGGER.user_record.$USERFIELD.$$" | awk -F\, '{print $6}' | sed s/\"//g )
SALT4=$( cat "/tmp/.BUGGER.user_record.$USERFIELD.$$" | awk -F\, '{print $7}' | sed s/\"//g )

# Grab password change time

CHANGETIME=$( cat "/tmp/.BUGGER.user_record.$USERFIELD.$$" | awk -F\, '{print $3}' | sed s/\"//g )

# Now let's generate the hash from the password supplied


# Salt the password
echo -n "$PASSFIELD" |tr '!-~' 'P-~!-O' > /tmp/.BUGGER.Pass_compliance_check1.$$
sed s/"$SALT2"/"$SALT1"/g /tmp/.BUGGER.Pass_compliance_check1.$$ > /tmp/.BUGGER.Pass_compliance_check2.$$
STAGE1=$( cat /tmp/.BUGGER.Pass_compliance_check2.$$ )
echo -n "$STAGE1" > /tmp/.BUGGER.Pass_compliance_check1.$$
echo "$CHANGETIME" >> /tmp/.BUGGER.Pass_compliance_check1.$$

sed s/"$SALT4"/"$SALT3"/g /tmp/.BUGGER.Pass_compliance_check1.$$ > /tmp/.BUGGER.Pass_compliance_check2.$$

# Generate the HASH

md5sum /tmp/.BUGGER.Pass_compliance_check2.$$ > /tmp/.BUGGER.Pass_compliance_check1.$$

# Only interested in the Sum itself

awk -F\  '{print $1}' /tmp/.BUGGER.Pass_compliance_check1.$$ > /tmp/.BUGGER.Pass_compliance_check2.$$

# Load it into a variable

SUPPLIEDSUM=$( cat /tmp/.BUGGER.Pass_compliance_check2.$$ )



# Do they match???

if [ "$SUPPLIEDSUM" == "$VALIDPASS" ]
then
# Supplied 'Old' Password is valid
PASSFIELD=""
process_Change

fi

# Password was invalid


ERROR_TITLE="ACCESS DENIED"
ERROR_TEXT1="The Old Password you provided was incorrect. Please "
ERROR_TEXT2="<a href=\"/BUGGER/passwd_upd.shtml\">try again</a>"
error_page



}


generate_html ()
{


/bin/cat << EOM
<html>
<head>
<title>BUGGER - Password Change Successful</title>
</head>
<body bgcolor="white"><font color="black">

<!-- Please leave Copyright Notice Intact -->


<!-- Generated by the BUGGER Project Management System -->
<!-- Copyright Ben Tasker 2009 -->
<!-- Released under the GNU GPL V3 -->
<!-- See http://benscomputer.no-ip.org/LICENSE -->
<!-- Obtain BUGGER from http://benscomputer.no-ip.org/2009/Nov/213301112009.shtml -->

<!-- Thanks --> 

<b><center>Password Change Form</b></center>
<br><br>
<a href="$NONSSLWEBSERVER/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br>
<hr>
<br><br>
The password for user $USERFIELD has been successfully changed. The change takes effect immediately.<br><br><br>
<br><br><br>
<a href="$NONSSLWEBSERVER/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br>
<hr><br><br>
EOM

./BUGGER_generate_footer.sh

/bin/cat << EOM
<!-- Please leave Copyright Notice Intact -->


<!-- Generated by the BUGGER Project Management System -->
<!-- Copyright Ben Tasker 2009 -->
<!-- Released under the GNU GPL V3 -->
<!-- See http://benscomputer.no-ip.org/LICENSE -->
<!-- Obtain BUGGER from http://benscomputer.no-ip.org/2009/Nov/213301112009.shtml -->


<!-- Thanks --> 

</body>
</html>
EOM


exit_function




}

# Function main











# Set our variables

# We've been supplied with username & Password

# Username of the current user
USERNAME=$( echo "$REQUEST_URI" | sed -n 's/^.*USERNAME=\([^&]*\).*$/\1/p' )

# Username of the user who's password is being reset
USERFIELD=$( echo "$REQUEST_URI" | sed -n 's/^.*USERFIELD=\([^&]*\).*$/\1/p' )

# Get Remote Host Details
REMOTE_ADDR=$( /bin/env | grep "REMOTE_ADDR" | sed -n 's/^.*REMOTE_ADDR=\([^&]*\).*$/\1/p' )

# If they don't match then USERNAME will need to have admin rights before we can proceed

if [ "$USERNAME" != "$USERFIELD" ]
then

AUTH=$( ./BUGGER_auth_check.sh "$USERNAME" A "$REMOTE_ADDR" )

if [ "$AUTH" == "XD" ]
then
exit_function
fi

if [ "$AUTH" == "N" ]
then

ERROR_TITLE="Access Denied"
ERROR_TEXT1="You do not appear to have the correct privileges for the action you are attempting to perform. Did you forget to "
ERROR_TEXT2="<a href=\"/BUGGER/Login.shtml\">Log In?</a>"
ERROR_TEXT3=""
error_page
fi

# User is authorised to change another users password
# We can continue
NEED_OLD_PASS="N"

process_Change

fi

# Usernames match, User is changing own password


PASSFIELD=$( echo "$REQUEST_URI" | sed -n 's/^.*PASSFIELD=\([^&]*\).*$/\1/p' )


check_supplied_password







