#!/bin/bash
#
#
# Filename: BUGGER_Frontpage_options.sh
#
#
# Description: An amalgamation of the previous front page scripts in an effort to improve
# system response times. Ultimately, using this script should enable us to easily reduce the
# number of Authorisation checks and Database calls we need to run in order to provide only the
# appropriate options to the user.
#
#
# There's a lot of un-necessary use of functions in this script, it may have a slight hit on performance
# but it makes it far easier to segregate each section!
#
#
# Copyright Ben Tasker 2009
# Released under the GNU GPL V3
# See http://benscomputer.no-ip.org/LICENSE
# for more details




# Functions go here



obtain_authority ()
{


# NOTE: I intend to add support for an additional call to the Auth checker.
# MX which will display the maximum privileges that the user has, it should
# speed this section up dramatically for ordinary users





# No additional menus for oridnary users
ADDITIONAL_MENUS="0"


# If username not blank, run the two auth checks that will be needed


if [ "$USERNAME" != "" ]
then


ADMIN_AUTH=$( ./BUGGER_auth_check.sh "$USERNAME" A )

# If ADMIN AUTH came back Y, we already know the answer to the next set of auth checks, no
# point slowing things down un-necessarily



if [ "$ADMIN_AUTH" == "Y" ]
then


DEVEL_AUTH="Y"
USER_IN_CHECK="Y"


# Also tell the system it's OK to display both sets of additional menus

ADDITIONAL_MENUS="2"
page_head_func
fi



DEVEL_AUTH=$( ./BUGGER_auth_check.sh "$USERNAME" D )

# If DEVEL_AUTH came back Y, we already know the answer to the next auth check, no
# point slowing things down un-necessarily

if [ "$DEVEL_AUTH" == "Y" ]
then


# Tell the system the user may view the Developers Additional Menu
ADDITIONAL_MENUS="1"

USER_IN_CHECK="Y"
page_head_func


fi



# Otherwise we need to check, as they may just not be a developer
USER_IN_CHECK=$( ./BUGGER_auth_check.sh $USERNAME U )



fi




page_head_func
}


page_head_func ()
{

# Start by outputting the Page header
/bin/cat << EOM
<html><head>
<title>BUGGER - Bug Reporting System - Index</title>
</head>
<body bgcolor="white">
<table width="100%"><tr>
<td width="33%"></td>

<td width="33%">
<b><center>BUGGER - Bug Reporting System</b></center>
</td>

<td width="33%" align="right">
EOM

# Previously, we ran CGI script
# Login_logout_option.sh here. So now we'll skip
# to that function

login_logout_option
}


login_logout_option ()
{

# Create the Login/Logout link
USER_IN_CHECK="$USER_IN_CHECK" WEBSERVER="$WEBSERVER" USERNAME="$USERNAME" ./BUGGER_login_logout_generate.sh

html_sect_2_func

}

html_sect_2_func ()
{

/bin/cat << EOM

</td>
</tr>
</table>
<br>
Welcome to the BUGGER Bug Reporting system.<br><br>
<br><hr><br>
<b><center><u>Existing Bugs</u></center></b>
<br><br>
<table width="100%">
<tr>

EOM


# At this point we ran CGI Script 
# BUGGER_Bug_view_type.sh
# So lets jump to it's new function

retrieve_project_list

}


Bug_view_type ()
{


# Allow the user to enter a Bug ID
# to access it directly
echo "<td><center>"
if [ "$DEVEL_AUTH" == "Y" ]
then
# User has developers rights

/bin/cat << EOM

<form action="Devel_View_bugs.shtml" METHOD="GET">
EOM

else
/bin/cat << EOM

<form action="View_Bugs.shtml" METHOD="GET">
EOM

fi

/bin/cat << EOM
<input type="hidden" name="USERNAME" value="$USERNAME">
Bug ID: <Input Type="text" Name="BUGID"><br><Input type="submit" Value="Load Bug Report">
</form></center></td>
<td>
<center>
<form action="Project_summary.shtml" method="get">
<input type="hidden" name="USERNAME" value="$USERNAME">
<select name="PROJ" id="PROJ">
EOM
cat /tmp/.Proejct_list_HTML.$$

/bin/cat << EOM
</select><br>
<input type="Submit" value="View Project Summary">
</form>
</center>
</td><td>
EOM

# Next we run todo_by_project.sh
# First we are going to run the Project name retrieval script though


todo_by_project

}

retrieve_project_list ()
{

# I'll mess around with caching at a later date


wget -q -O /tmp/.Project_list2.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=2&DBNAME=Bugs&TABLE=Projects"


# Strip out all the Quotes
sed s/\"//g /tmp/.Project_list2.$$ > /tmp/.Project_list.$$

# Tidy up
rm -f /tmp/.Project_list2.$$ 2> /dev/null


# Process the project list
while read -r a                    
do   

echo "$a" > /tmp/tmprecord1.$$

PRO_ID=$( cat /tmp/tmprecord1.$$ | awk -F\, '{print $1}' )


PROJECT_NAME=$( cat /tmp/tmprecord1.$$ | awk -F\, '{print $2}' )


/bin/cat << EOM >> /tmp/.Proejct_list_HTML.$$
<option value="$PRO_ID">$PROJECT_NAME</option>
EOM
rm -f /tmp/tmprecord1.$$


done < /tmp/.Project_list.$$



Bug_view_type


}

todo_by_project ()
{

# This function creates a list of all project names so the user
# can select it from a drop down.



/bin/cat << EOM
<center>
<form action="view_TODO.shtml" method="get">
<input type="hidden" Name="USERNAME" value="$USERNAME">
Project: <SELECT NAME="ProjectID">
EOM


# Output the generate project list
cat /tmp/.Proejct_list_HTML.$$


/bin/cat << EOM
</select><br><Input type="submit" Value="View TODO list"></form>

</center>
</td>
</tr></table>

EOM


# Move onto the New Bugs section

new_bugs


}

new_bugs ()
{

# Get the section header in place

/bin/cat << EOM
<hr><br>
<b><center><u>New Bugs</u></center></b>
<br><br><table width="100%">
<tr><td>
<center>

EOM

# Move onto creating the Report Bug button

report_bug_button
}

report_bug_button ()
{

# Couldn't be much simpler!

/bin/cat << EOM
<form action="Report_bug.shtml" METHOD="GET">
<input type="hidden" name="USERNAME" value="$USERNAME">
<Input type="submit"
Value="Report Bug"></form>


</center>
</td>
<td>
<center>

EOM

# Next we give Developer users the opportunity to add some TODO's to the list

add_new_todo_button

}

add_new_todo_button ()
{
# Again, couldn't be much simpler!

if [ "$DEVEL_AUTH" == "Y" ]
then
/bin/cat << EOM
<form action="TODO_Update.shtml" METHOD="GET">
<input type="hidden" name="USERNAME" value="$USERNAME">
<Input type="Submit" value="Update TODO List"></form>
EOM
fi

# Need this bit in there either way
/bin/cat << EOM
</td>
<td>


<center>

EOM


# Now we give them a button to update Changelogs
# Used to be Update_changelog_access.sh

Update_changelog_access



}

Update_changelog_access ()
{
# If they're a developer, Give them a button!

if [ "$DEVEL_AUTH" == "Y" ]
then

/bin/cat << EOM
<form action="/BUGGER/changelog_upd.shtml" METHOD="GET">
<input type="hidden" name="USERNAME" value="$USERNAME">
<input type="submit" value="Update Changelogs">
</form>
EOM


fi



# Need this next bit regardless

/bin/cat << EOM

</center>
</td>
</tr>
</table>

<br>

EOM

# Move onto the third default section

Reports_section_begin_func

}

Reports_section_begin_func ()
{
# Create the section Header

/bin/cat << EOM
<hr><br>
<b><center><u>Find a Bug</u></center></b>
<br><br>
<table width="100%">
<tbody>
<tr>
EOM

# This is where we previously called CGI
# by_project.sh
#

# Lets move onto that function


view_bugs_for_project_menu


}

view_bugs_for_project_menu ()
{

# Create a drop down menu of all the available projects.
# We did the groundwork in function retrieve_project_list

/bin/cat << EOM
<td>
<form action="/BUGGER/View_Bugs_for_project.shtml" method="get">
<input type="hidden" Name="USERNAME" value="$USERNAME">
Project: <SELECT NAME="Project">
EOM

cat /tmp/.Proejct_list_HTML.$$

/bin/cat << EOM
</select><Input type="submit" Value="Find Bugs"></form></td>
EOM


# Move onto the next area of the table


reports_table_cell2_func
}

reports_table_cell2_func ()
{
# This isn't named after a script as I currently have no function to put here
# other than to create the table cell

/bin/cat << EOM
<td>
<!-- Searching by Date will eventually go here -->


</td>

EOM
reports_table_cell3_func

}

reports_table_cell3_func ()
{
# This isn't named after a script as I currently have no function to put here
# other than to create the table cell

/bin/cat << EOM
<td>
<!-- Searching by Bug Status will eventually go Here -->


</td>

EOM

end_reports_section_func

}

end_reports_section_func ()
{
# Close off the reports section

/bin/cat << EOM
</tr>
</tbody>
</table>
<hr>
EOM


# The next set of functions are for Developers/Admins only, so if the user is neither we
# can skip straight past them

if [ "$ADDITIONAL_MENUS" != "0" ]
then

Dev_opts

else
page_footer_function


fi


}

Dev_opts ()
{
/bin/cat << EOM
<br><br>
<b><u><center>Developer Functions</b></u></center>
<br><br>




<table width="100%">
<tbody>
<tr>
<td>
<form action="Document_submit.shtml" method="get">
<input type="hidden" name="USERNAME" value="$USERNAME">
<input type="submit" value="Register Documentation">
</form>
</td>


<td>

<form action="Release_submit.shtml" method="get">
<input type="hidden" name="USERNAME" value="$USERNAME">
<input type="submit" value="Register Release">
</form>




</td>
<td>

</td>
</tr>
</tbody>
</table>
<br><br>
<hr>
EOM

ADDITIONAL_MENUS=$(( $ADDITIONAL_MENUS - 1 ))


if [ "$ADDITIONAL_MENUS" == "1" ]
then

# User can also see Admin Menu
Adm_opts

else
# User does not have Admin rights, Start closing the HTML

page_footer_function

fi


}

Adm_opts ()
{
/bin/cat << EOM
<br><br>
<b><u><center>Administrator Functions</b></u></center>
<br><br>

<table width="100%">
<tr>
<td align="right"><b>User Management:</b></td>
<td align="left"><center><form action="/BUGGER/User_create_edit.shtml" METHOD="GET">
<input type="hidden" name="USERNAME" value="$USERNAME">
<input type="hidden" name="ACTION" value="NEW">
<input type="submit" value="Create New User">
</form></center>
</td>
<td><center><form action="/BUGGER/User_create_edit.shtml" METHOD="GET">
<input type="hidden" name="USERNAME" value="$USERNAME">
<input type="hidden" name="ACTION" value="EDIT">
Username: <Input type="text" name="USERFIELD"> <input type="submit" value="Edit User">
</form></center></td>

<td><form action="/BUGGER/Cache_maintain.shtml" METHOD="GET">
<input type="hidden" name="USERNAME" value="$USERNAME">
<input type="submit" value="Manage Temporary/Cache files">
</form>
</td>
</tr>
</table><br>
<hr>
EOM


page_footer_function
}

page_footer_function ()
{
/bin/cat << EOM
<br><br>
EOM

./BUGGER_generate_footer.sh

/bin/cat << EOM
</body>
</html>
EOM


# Tidy up before we leave

exit_function

}

exit_function ()
{


rm -f /tmp/.Project_list.$$ 2> /dev/null


exit

}




# Function MAIN

# Set the MIME-TYPE
echo Content-Type: text/html
echo


# Grab our config
./BUGGER_config.sh imascript /tmp/BUGGER.front_page_process.conf.$$

source /tmp/BUGGER.front_page_process.conf.$$
rm -f /tmp/BUGGER.front_page_process.conf.$$ 2> /dev/null


# Retrieve the username (if any!)
USERNAME=$( /bin/env | grep "REQUEST_URI" | sed -n 's/^.*USERNAME=\([^&]*\).*$/\1/p' )


# Check their level of authorisation
obtain_authority