#!/bin/bash
#
#
# Filename: BUGGER_Todo_process.sh
#
# TODO list maintenance
#
#
# Copyright Ben Tasker 2009
# Released under GNU GPL v3
#
# See http://benscomputer.no-ip.org/LICENSE for more details


# HTML Referrer to send the following variables
#
# ProjectID
# Username
# Task
# Completed (Defaults to N for new tasks)
# 
# TaskID (Primary Key Autopopulated by this script)
# Date field will be autopopulated by this script

# Database Specific Configuration


./BUGGER_config.sh imascript /tmp/BUGGER.auth_process.conf.$$

source /tmp/BUGGER.auth_process.conf.$$
rm -f /tmp/BUGGER.auth_process.conf.$$ 2> /dev/null


DBROOT="Bugs"
TABLE="Todo"




# Functions go here


generate_html ()
{
# Generate HTML to inform user of Status


/bin/cat << EOM
<html>
<head><title>BUGGER - Todo list update - $STATUS_TEXT </title>
<body bgcolor="white"><center><b>Todo list update - $STATUS_TEXT</b></center><br><a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br>
<hr><br><br>

<br><br>
Details follow:<br><br>
$STATUS_Details<br><Br>
<a href="TODO_Update.shtml?USERNAME=$USERNAME">Add another TODO</a><br><br>
<br><br><br><br><br><bR><br><br><br>

<hr>
<a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br><br>

EOM


./BUGGER_generate_footer.sh

/bin/cat << EOM

</body>
</html>
EOM

# Finished!

exit
}









insert_record ()
{
# insert the record into the database

# We need to get the next primary key

wget -q -O /tmp/.claims.todo.pk.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=7&DBNAME=$DBROOT&TABLE=$TABLE&QCOL=2"

NEW_PK=$( cat /tmp/.claims.todo.pk.$$ )

# Set Date
DATE=$( date +'%d/%m/%Y')



# Table layout as follows

# ProjectID - Col 1
# TaskID (Primary Key Autopopulated by this script) - Col2
# Username - Col 3
# Date field will be autopopulated by this script - Col 4
# Task - Col 5
# Completed (Defaults to N for new tasks) - Col 6
# 


wget -q -O /tmp/.claims.todo.stat.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=1&DBNAME=$DBROOT&TABLE=$TABLE&COL1=$ProjectID&COL2=$NEW_PK&COL3=$Username&COL4=$DATE&COL5=$Task&COL6=$Completed"

# Check whether we were successful

STATUS_CODE=$( cat /tmp/.claims.todo.stat.$$ )

if [ "$STATUS_CODE" != "SUCCESS" ]
then
# Something went wrong

STATUS_TEXT="Failed - Error"
STATUS_Details="Error Details: $STATUS_CODE"

# Tidy up
rm -f /tmp/.claims.todo.pk.$$ 2> /dev/null
rm -f /tmp/.claims.todo.stat.$$ 2> /dev/null

# Generate the html
generate_html
fi

# Insertion was successful

STATUS_TEXT="Successful"
STATUS_Details="Your TaskID is $NEW_PK"


# Tidy up
rm -f /tmp/.claims.todo.pk.$$ 2> /dev/null
rm -f /tmp/.claims.todo.stat.$$ 2> /dev/null

# Generate the HTML

generate_html
}


input_validate ()
{
# Ensure all required fields were completed

# All fields are required

X="0"
Y="0"
Z="0"
A="0"

if [ "$ProjectID" == "" ]
then
X="1"
fi


if [ "$Username" == "" ]
then
Y="1"
fi


if [ "$Task" == "" ]
then
Z="1"
fi

if [ "$Completed" == "" ]
then
A="1"
fi

VALIDATION_CHECK=$(( $X + $Y + $Z + $A ))

if [ "$VALIDATION_CHECK" != "0" ]
then
# Something is missing

STATUS_TEXT="Failed - Required field missing"
STATUS1="You failed to enter all required information<br>"
STATUS2="All fields are required<br><br>"
STATUS3="You Entered;<br>"
STATUS4="ProjectID: $ProjectID<br>"
STATUS5="Your Username: $Username<br>"
STATUS6="Task Details: $Task<br>"
STATUS7="Completed: $Completed<br><br>"
STATUS8="Please go back and enter <b>All</b> Details"
STATUS_Details="$STATUS1 $STATUS2 $STATUS3 $STATUS4 $STATUS5 $STATUS6 $STATUS7 $STATUS8"
generate_html

else


# Continue!
insert_record

fi


# If we hit this bit, somethings gone amiss 
exit
}







foxtrot_oscar ()
{
# Authentication failed, tell user to go away

# They may just have forgotten to log in, so a) be polite
# b) provide a link that will submit their request if they
# authenticate properly (save re-entering everything!)

/bin/cat << EOM
<html><head><title>Authentication Failed</title></head>
<body bgcolor="white"><b><center><u>Authentication Failed</b></center></u>

<br><br>

The system was unable to Authenticate you. Are you supposed to be here? <br><br>
If you believe that you are then please 

<a href="/BUGGER/Devel_login.shtml?REFER=Todo_process.shtml&FIELD1=ProjectID&FIELD3=Username&FIELD4=Task&FIELD5=Completed&FIELDT1=$ProjectID&FIELDT3=$Username&FIELDT4=$Task&FIELDT5=$Completed&USERNAME=$USERNAME">login</a><br><br>
<a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br><br>
EOM
./BUGGER_generate_footer.sh

/bin/cat << EOM
</body></html>
EOM

# All we need to do for now!
exit

}


# Function Main

# Output the MIME Type

echo Content-Type: text/html
echo




# Run authentication script, Default DENY
AUTH=$( ./BUGGER_auth_check.sh "$USERNAME" D )

./authentication_script.sh

if [ "$AUTH" == "XD" ]
then
# Host explicitly Denied. Don't do anything, just disconnect
exit
fi

# Grab the variables from the URI

REQUEST_URI=$( /bin/env | grep "REQUEST_URI" )
USERNAME=$( echo "$REQUEST_URI" | sed -n 's/^.*USERNAME=\([^&]*\).*$/\1/p' )

ProjectID=$( echo "$REQUEST_URI" | sed -n 's/^.*ProjectID=\([^&]*\).*$/\1/p' )

Username=$( echo "$REQUEST_URI" | sed -n 's/^.*Username=\([^&]*\).*$/\1/p' )
Task=$( echo "$REQUEST_URI" | sed -n 's/^.*Task=\([^&]*\).*$/\1/p' )
Completed=$( echo "$REQUEST_URI" | sed -n 's/^.*Completed=\([^&]*\).*$/\1/p' )



# Check the authentication result
if [ "$AUTH" != "Y" ]
then

# Tell them to go away, or to log in first
foxtrot_oscar

fi


# Authentication was successful, proceed


input_validate