#!/bin/bash
#
# Filename: BUGGER_auth_check.sh
#
# Script to check which privileges a user has
#
# Copyright Ben Tasker 2009
# Released under the GNU GPL V3
# See http://benscomputer.no-ip.org/LICENSE
# for more details


# Usage:
#
# BUGGER_auth_check.sh USERNAME Required_privileges_code
#
# U - User
# M - Moderator
# D - Developer
# A - Administrator
#
# Example:
#
# BUGGER_auth_check.sh BTasker A

# Variables

USERNAME="$1"
REQUIRED_PRIVS="$2"



# Insert functions here

check_privs ()
{
# Compare the users privileges with what is requested


source /tmp/.BUGGER.AUTH.$USERNAME.privs.cache

if [ "$DISABLED" == "Y" ]
then
echo "D"
exit_function
fi



if [ "$REQUIRED_PRIVS" == "M" ]
then
if [ "$MODPRIVS" == "Y" ]
then
# User has the privileges
echo "Y"
exit_function
else
echo "N"
exit_function
fi
fi


if [ "$REQUIRED_PRIVS" == "D" ]
then
if [ "$DEVPRIVS" == "Y" ]
then
# User has the privileges
echo "Y"
exit_function
else
echo "N"
exit_function
fi
fi


if [ "$REQUIRED_PRIVS" == "A" ]
then
if [ "$ADMPRIVS" == "Y" ]
then
# User has the privileges
echo "Y"
exit_function
else
echo "N"
exit_function
fi
fi


# If we hit this point, something has gone wrong
echo "ERROR"
exit_function
}


retrieve_record ()
{
# Retrieve the users record

wget -q -O /tmp/BUGGER.authcheck.$USERNAME.privs.new.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=4&DBNAME=Bugs&TABLE=Users&QCOL=1&QSTRING=$USERNAME" > /dev/null 2> /dev/null

STATUS=$( cat /tmp/BUGGER.authcheck.$USERNAME.privs.new.$$ )

if [ "$STATUS" == "NORESULTS" ]
then
# Username doesn't ecist
echo "N"
exit_function

fi

# Does the user have Moderator Privileges?
MODPRIVS=$( cat /tmp/BUGGER.authcheck.$USERNAME.privs.new.$$ | awk -F\, '{print $5}' | sed s/\"//g)

# Does the user have Developer Privileges?
DEVPRIVS=$( cat /tmp/BUGGER.authcheck.$USERNAME.privs.new.$$ | awk -F\, '{print $6}' | sed s/\"//g)

# Does the user have Administrator Privileges?

ADMPRIVS=$( cat /tmp/BUGGER.authcheck.$USERNAME.privs.new.$$ | awk -F\, '{print $7}' | sed s/\"//g)

DISABLED=$( cat /tmp/BUGGER.authcheck.$USERNAME.privs.new.$$ | awk -F\, '{print $4}' | sed s/\"//g)

# Create the Cachefile for later use

/bin/cat << EOM > /tmp/.BUGGER.AUTH.$USERNAME.privs.cache
DISABLED="$DISABLED"
MODPRIVS="$MODPRIVS"
DEVPRIVS="$DEVPRIVS"
ADMPRIVS="$ADMPRIVS"
EOM

# Store the checksum
echo "$NEWSUM" > /tmp/.BUGGER.AUTH.$USERNAME.privs.cache.sum

# Move on to calculate whether access should be allowed/denied

check_privs
}



cache_check ()
{
# Check for the existence of a Cachefile

if [ -e /tmp/.BUGGER.AUTH.$USERNAME.privs.cache ]
then
# Cache file exists, is it valid?

OLDSUM=$( cat /tmp/.BUGGER.AUTH.$USERNAME.privs.cache.sum )

if [ "$OLDSUM" == "$NEWSUM" ]
then
# Cache is valid, use it

CACHE_IN_USE="Y"

check_privs
fi

# Sums don't match

fi

# Either sums don't match, or no cache file exists.
# Make one.
CACHE_IN_USE="N"
retrieve_record

}

retrieve_checksum ()
{
# Retrieve a checksum of the Users table
wget -q -O /tmp/BUGGER.authcheck.$USERNAME.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=14&DBNAME=Bugs&TABLE=Users" > /dev/null 2> /dev/null
NEWSUM=$( cat /tmp/BUGGER.authcheck.$USERNAME.$$ )
cache_check
}


exit_function ()
{
# Tidy up and exit

rm -f /tmp/BUGGER.authcheck.$USERNAME.privs.new.$$ 2> /dev/null
rm -f /tmp/BUGGER.authcheck.$USERNAME.$$ 2> /dev/null
exit
}


initial_check ()
{
# is the user actually logged in?

# First check is easy
# Is username blank?

if [ "$USERNAME" == "" ]
then
# Clearly they're not logged in

echo "N"
exit_function



fi



if [ -e /tmp/.BUGGER_Active.users.$USERNAME ]
then
# Userfile exists
# Extend their gracetime

echo "10" > /tmp/.BUGGER_Active.users.$USERNAME

if [ "$REQUIRED_PRIVS" == "U" ]
then
echo "Y"
exit_function

fi



retrieve_checksum

else

# User not logged in
echo "N"
exit_function

fi


}


host_check ()
{
# This will eventually check the hostname against our blacklist
echo "" > /dev/null


initial_check
}



# Function main

./BUGGER_config.sh imascript /tmp/BUGGER.auth_process.conf.$$

source /tmp/BUGGER.auth_process.conf.$$
rm -f /tmp/BUGGER.auth_process.conf.$$ 2> /dev/null



host_check