#!/bin/bash
#
# Filename: User_create_edit_process.sh
#
# Process the data sent to us by the user creation/editing
# page. The insert that data into the database, removing the
# existing record if it exists.
#


# Retrieve Variables



./BUGGER_config.sh imascript /tmp/BUGGER.auth_process.conf.$$

source /tmp/BUGGER.auth_process.conf.$$
rm -f /tmp/BUGGER.auth_process.conf.$$ 2> /dev/null



# Functions go here


update_user_record ()
{
# Update existing record

# First find the line number

wget -q -O /tmp/BUGGER.user_create.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=5&DBNAME=Bugs&TABLE=Users&QCOL=1&QSTRING=$USERFIELD"

LINE_NO=$( cat /tmp/BUGGER.user_create.$$ )

# Delete the record

wget -q -O /tmp/BUGGER.user_create.$$.1 "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=9&LINENO=$LINE_NO&DBNAME=Bugs&TABLE=Users"

STATUS=$( cat /tmp/BUGGER.user_create.$$.1 )

if [ "$STATUS" != "SUCCESS" ]
then
# Failed for some reason

ERROR_TITLE="<font color=\"red\">Error: Failed to remove old record</font>"
ERROR_TEXT1="Uh-oh, something went wrong.<br><br> Claims_DB returned the following<br><br>$STATUS"

error_page

fi

# We successfully removed the old record, now insert the new


wget -q -O /tmp/BUGGER.user_create.$$.2 "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=1&DBNAME=Bugs&TABLE=Users&COL1=$USERFIELD&COL2=$DISPLAY_NAME&COL3=$E_MAIL&COL4=$DISABLED&COL5=$MODERATOR&COL6=$DEVELOPER&COL7=$ADMINISTRATOR&COL8=$USERNAME&COL9=$DATE"

# Check the status

STATUS=$( cat /tmp/BUGGER.user_create.$$.2 )

if [ "$STATUS" == "SUCCESS" ]
then

# The command completed successfully. Generate the HTML to tell the user we're good to go!
generate_html

fi

# Nuts something went wrong
ERROR_TITLE="<font color=\"red\">Error: Failed to insert new record</font>"
ERROR_TEXT1="Uh-oh, something went wrong.<br><br> Claims_DB returned the following<br><br>$STATUS"
ERROR_TEXT2="<br><br><font color=\"red\">The old record was deleted, but the new could not be inserted. Currently user $USERFIELD no longer exists!</font>"
error_page


}


create_new_record ()
{
# Create a new user record

wget -q -O /tmp/BUGGER.user_create.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=1&DBNAME=Bugs&TABLE=Users&COL1=$USERFIELD&COL2=$DISPLAY_NAME&COL3=$E_MAIL&COL4=$DISABLED&COL5=$DEVELOPER&COL6=$ADMINISTRATOR&COL7=$USERNAME&COL8=$DATE"

# Check the status

STATUS=$( cat /tmp/BUGGER.user_create.$$ )

if [ "$STATUS" == "SUCCESS" ]
then

generate_html

fi

# Something went wrong


ERROR_TITLE="<font color=\"red\">Access Denied: Failed to insert record</font>"
ERROR_TEXT1="Uh-oh, something went wrong.<br><br> Claims_DB returned the following<br><br>$STATUS"

error_page

}

error_page ()
{

/bin/cat << EOM
<html>
<head>
<title> BUGGER - User Update Error </title>
</head>
<body bgcolor="white">
<center><b><u>$ERROR_TITLE</b></u></center><br><br>
<a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br>
<hr>
<br><br>
$ERROR_TEXT1
$ERROR_TEXT2
<br><br>
<hr>
<br>
EOM

./BUGGER_generate_footer.sh

/bin/cat << EOM
</body>
</html>
EOM


exit_function
}



generate_html ()
{
/bin/cat << EOM
<html>
<head><title>BUGGER - User $USERFIELD Updated</title></head>
<body bgcolor="white">
<center><b><u>User $USERFIELD Updated</b></u></center><br><br>
<a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br>
<hr>
<br><br>
Your request was <font color="green">SUCCESSFUL</font> and the new settings for
user $USERFIELD have successfully been stored in the database. Changes take effect
immediately.<br><br>
If this is a new user, you will need to <a href="/BUGGER/passwd_upd.shtml?USERFIELD=$USERFIELD&USERNAME=$USERNAME">Set the users password</a><br><br>
<br>
<a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br><br>
<hr><br><br>
EOM

./BUGGER_generate_footer.sh

/bin/cat << EOM
<br>
</body>
</html>
EOM


exit_function
}


exit_function ()
{

rm -f /tmp/BUGGER.user_create.$$.1 2> /dev/null
rm -f /tmp/BUGGER.user_create.$$.2 2> /dev/null
rm -f /tmp/BUGGER.user_create.$$ 2> /dev/null


exit
}





# Function main


# Output Content-type

echo Content-Type: text/html
echo



# Authentication script goes here
#
# Run my auth script!
REQUEST_URI=$( /bin/env | grep "REQUEST_URI" )
USERNAME=$( echo "$REQUEST_URI" | sed -n 's/^.*USERNAME=\([^&]*\).*$/\1/p' )


AUTH=$( ./BUGGER_auth_check.sh "$USERNAME" A )

if [ "$AUTH" == "XD" ]
then
# Host explicitly denied. Don't do anything, just disconnect

exit_function
fi



if [ "$AUTH" == "Y" ]
then
# User is authorised, continue


# Are we editing a record, or are we creating a new record

ACTION=$( echo "$REQUEST_URI" | sed -n 's/^.*ACTION=\([^&]*\).*$/\1/p' )


USERFIELD=$( echo "$REQUEST_URI" | sed -n 's/^.*USERFIELD=\([^&]*\).*$/\1/p' )
DISPLAY_NAME=$( echo "$REQUEST_URI" | sed -n 's/^.*DISPLAY_NAME=\([^&]*\).*$/\1/p' )
E_MAIL=$( echo "$REQUEST_URI" | sed -n 's/^.*E_MAIL=\([^&]*\).*$/\1/p' )
DISABLED=$( echo "$REQUEST_URI" | sed -n 's/^.*DISABLED=\([^&]*\).*$/\1/p' )
DEVELOPER=$( echo "$REQUEST_URI" | sed -n 's/^.*DEVELOPER=\([^&]*\).*$/\1/p' )
ADMINISTRATOR=$( echo "$REQUEST_URI" | sed -n 's/^.*ADMINISTRATOR=\([^&]*\).*$/\1/p' )
MODERATOR=$( echo "$REQUEST_URI" | sed -n 's/^.*MODERATOR=\([^&]*\).*$/\1/p' )
DATE=$( date +'%d-%m-%Y %H:%m' )

if [ "$ACTION" == "EDIT" ]
then
# Go to the EDIT Function

update_user_record

fi



if [ "$ACTION" == "NEW" ]
then
# Goto the create new function

create_new_record


fi


# ACTION was not specified, we don't know what to do!
# Create an error page


ERROR_TITLE="Action not specified"
ERROR_TEXT="You didn't specify an Action, I don't know whether you are wanting to create a new record or to edit an existing one. "
ERROR_TEXT_L2="<br><a href=/BUGGER/User_create_edit.shtml?ACTION=NEW&USERNAME=$USERNAME>Create New</a><br><br>"
ERROR_TEXT_L3="<form action=\"/BUGGER/User_create_edit.shtml\" ACTION=\"GET\" > Username: <input type=\"text\" name=\"USERFIELD\"><input type=\"submit\" value=\"Edit User\"></form><br><br><a href=/BUGGER/Index.shtml?USERNAME=$USERNAME>Home</a><br>"
error_message


else
# User is not authorised


ERROR_TITLE="<font color=\"red\">Access Denied</font>"
ERROR_TEXT="You appear to lack the necessary access privileges. Did you forget to <a href=\"/BUGGER/Login.shtml\">Log In?</a><br><br>"
ERROR_TEXT_L2=""
ERROR_TEXT_L3="<a href=\"/BUGGER/Index.shtml?USERNAME=$USERNAME\">Home</a><br><br>"
error_message




fi

