#!/bin/bash
#
# bug_file.sh
#
# Parse information passed to us by the Bug Filing form
# Then pass it onto the nominated database server
#
# Adapted from the script Changelog_upd.sh
#
# Copyright Ben Tasker 2009
# Released under the GNU GPL
#
# See Http://benscomputer.no-ip.org/LICENSE



./BUGGER_config.sh imascript /tmp/BUGGER.auth_process.conf.$$

source /tmp/BUGGER.auth_process.conf.$$
rm -f /tmp/BUGGER.auth_process.conf.$$ 2> /dev/null



# Set the MIME
echo Content-Type: text/html
echo


REQUEST_URI=$( /bin/env | grep "REQUEST_URI" )
USERNAME=$( echo "$REQUEST_URI" | sed -n 's/^.*USERNAME=\([^&]*\).*$/\1/p' )


# Check Authorisation

AUTH=$( ./BUGGER_auth_check.sh $USERNAME D )

if [ "$AUTH" == "XD" ]
then
# User is explicitly denied. Drop the connection
exit

fi

# Grab the input that has been sent to us
PROJECT_ID=$( echo "$REQUEST_URI" | sed -n 's/^.*PROJECT_ID=\([^&]*\).*$/\1/p' )
PRIMKEY=$( echo "$REQUEST_URI" | sed -n 's/^.*PrimKey=\([^&]*\).*$/\1/p' )
Date=$( echo "$REQUEST_URI" | sed -n 's/^.*Date=\([^&]*\).*$/\1/p' )
Email=$( echo "$REQUEST_URI" | sed -n 's/^.*Email=\([^&]*\).*$/\1/p' )
Name=$( echo "$REQUEST_URI" | sed -n 's/^.*Name=\([^&]*\).*$/\1/p' )
Details=$( echo "$REQUEST_URI" | sed -n 's/^.*Details=\([^&]*\).*$/\1/p' )
STATUS=$( echo "$REQUEST_URI" | sed -n 's/^.*Stat=\([^&]*\).*$/\1/p' )
Devel_Notes=$( echo "$REQUEST_URI" | sed -n 's/^.*Develnotes=\([^&]*\).*$/\1/p' )
Developer=$( echo "$REQUEST_URI" | sed -n 's/^.*Devel=\([^&]*\).*$/\1/p' )


if [ "$AUTH" == "Y" ]
then

# User is authorised




# Begin providing feedback.
/bin/cat << EOM
<html><head><title>BUGGER - Bug $PRIMKERY</title></head><body bgcolor="white"><font color="black">
<b><u><center>Bug Update</center></u></b><br><br><a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br><hr><br>
Your bug has been received and processing was <b>
EOM

# Remove the original record, find out the line number by using a Query

wget -q -O /tmp/$PROJECT_ID.editrecord_lineno.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=5&DBNAME=Bugs&TABLE=Bugs&QCOL=2&QSTRING=$PRIMKEY" > /dev/null 2> /dev/null

LINE_NUMBER_DEL=$( cat /tmp/$PROJECT_ID.editrecord_lineno.$$ )


wget -q "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=9&DBNAME=Bugs&TABLE=Bugs&LINENO=$LINE_NUMBER_DEL" > /dev/null 2> /dev/null

rm -f /tmp/$PROJECT_ID.editrecord_lineno.$$ > /dev/null 2> /dev/null

# We don't need to URL unencode, the listener will do that
# Send it to the database

wget -q -O /tmp/$PROJECT_ID.changelog.upd "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=1&DBNAME=Bugs&TABLE=Bugs&COL1=$PROJECT_ID&COL2=$PRIMKEY&COL3=$Date&COL4=$Email&COL5=$Name&COL6=$Details&COL7=$STATUS&COL8=$Devel_Notes&COL9=$Developer" > /dev/null 2> /dev/null

STATUS=$( cat /tmp/$PROJECT_ID.changelog.upd )





if [ "$STATUS" != "SUCCESS" ]
then
/bin/cat << EOM


<font color="red">UNSUCCESSFUL</font><br><br>
The error code returned by Claims_DB was $STATUS
<br><br>
You can check the status of your Bug Report <a href="/BUGGER/View_Bugs.shtml?BUGID=$PRIMKEY&USERNAME=$USERNAME" >here</a><br><br>
EOM
else

/bin/cat << EOM
<font color="green">SUCCESSFUL</font>. <br><br>
You can check the status of your Bug Report <a href="/BUGGER/View_Bugs.shtml?BUGID=$PRIMKEY&USERNAME=$USERNAME" >here</a><br><br>
EOM

fi

/bin/cat << EOM
<br><br><br><a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br><br><hr><br>
EOM

./BUGGER_generate_footer.sh


/bin/cat << EOM

</body></html>
EOM






exit

else

# User is not authorised to be here
# Begin providing feedback.
/bin/cat << EOM
<html><head><title>BUGGER - Bug $PRIMKERY - Access Denied</title></head><body bgcolor="white"><font color="black">
<b><u><center><font color="red">Access Denied</font></center></u></b><br><br><a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br><hr><br>
You do not appear to have the requisite privileges for the action you are trying to perform. Did you forget to <a href="/BUGGER/Login.shtml">log in.</a><br><br>
<br><a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a><br><hr><br><br>

EOM
./BUGGER_generate_footer.sh

/bin/cat << EOM
</body>
</html>
EOM

exit

fi