#!/bin/bash
#
# bug_file.sh
#
# Parse information passed to us by the Bug Filing form
# Then pass it onto the nominated database server
#
# Adapted from the script Changelog_upd.sh
#
# Copyright Ben Tasker 2009
# Released under the GNU GPL
#
# See Http://benscomputer.no-ip.org/LICENSE



./BUGGER_config.sh imascript /tmp/BUGGER.auth_process.conf.$$

source /tmp/BUGGER.auth_process.conf.$$
rm -f /tmp/BUGGER.auth_process.conf.$$ 2> /dev/null



# Set the MIME
echo Content-Type: text/html
echo


REQUEST_URI=$( /bin/env | grep "REQUEST_URI" )
USERNAME=$( echo "$REQUEST_URI" | sed -n 's/^.*USERNAME=\([^&]*\).*$/\1/p' )



# Grab the input that has been sent to us
BUG_ID=$( echo "$REQUEST_URI" | sed -n 's/^.*BUGID=\([^&]*\).*$/\1/p' )

# We don't need to URL unencode, the listener will do that
# Send it to the database

wget -q -O /tmp/.BUGREPORT_DETAILS.upd.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=4&DBNAME=Bugs&TABLE=Bugs&QSTRING=$BUG_ID&QCOL=2&PRIMKEY=1"

# Retrieve and print existing bug comments - Used to be retrived later, but easier for caching detection if we do it this way.

wget -q -O /tmp/.BUGREPORT_DETAILS.updC.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=4&DBNAME=Bugs&TABLE=Comments&QSTRING=$BUG_ID&QCOL=1"

# Check that the Captcha settings haven't changed

wget -q -O /tmp/BUGGER.bugview.comment.captcha.$$ "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=4&DBNAME=Bugs&TABLE=Security&QCOL=1&QSTRING=Comments"

# Grab the users details for use in the comments form
if [ -e /tmp/.BUGGER_user_details.$USERNAME ]
then
source /tmp/.BUGGER_user_details.$USERNAME
else
USER_REAL_NAME=""
USER_EMAIL_ADDRESS=""
fi


# Lets use Caching if possible.

md5sum /tmp/.BUGREPORT_DETAILS.upd.$$ > /tmp/.BUGREPORT_DETAILS.upd.$$.new1
md5sum /tmp/.BUGREPORT_DETAILS.updC.$$ > /tmp/.BUGREPORT_DETAILS.upd.$$.new2
md5sum /tmp/BUGGER.bugview.comment.captcha.$$ > /tmp/BUGGER.bugview.comment.captcha.$$.2

# Rather than processing two Md5 Sums, we're going to cheat and combine them. Then we are going to create a sum of the result.

awk -F\  '{print $1}' /tmp/.BUGREPORT_DETAILS.upd.$$.new1 > /tmp/.BUGREPORT_DETAILS.upd.$$.new3
awk -F\  '{print $1}' /tmp/.BUGREPORT_DETAILS.upd.$$.new2 >> /tmp/.BUGREPORT_DETAILS.upd.$$.new3
awk -F\  '{print $1}' /tmp/BUGGER.bugview.comment.captcha.$$.2 >> /tmp/.BUGREPORT_DETAILS.upd.$$.new3

md5sum /tmp/.BUGREPORT_DETAILS.upd.$$.new3 > /tmp/.BUGREPORT_DETAILS.upd.$$.new4
awk -F\  '{print $1}' /tmp/.BUGREPORT_DETAILS.upd.$$.new4 > /tmp/.BUGREPORT_DETAILS.upd.$$.new

# Quick tidy up

rm -f /tmp/.BUGREPORT_DETAILS.upd.$$.new4 2> /dev/null
rm -f /tmp/.BUGREPORT_DETAILS.upd.$$.new3 2> /dev/null
rm -f /tmp/.BUGREPORT_DETAILS.upd.$$.new2 2> /dev/null
rm -f /tmp/.BUGREPORT_DETAILS.upd.$$.new1 2> /dev/null
rm -f /tmp/BUGGER.bugview.comment.captcha.$$.2 2> /dev/null
# Time to see if the cache is valid

# First, is there a cache?

if [ -e /tmp/.Bugview_$BUG_ID.new.sum ]
then
# Yes there is

NEWSUM=$( cat /tmp/.BUGREPORT_DETAILS.upd.$$.new )
OLDSUM=$( cat /tmp/.Bugview_$BUG_ID.new.sum )

if [ "$NEWSUM" == "$OLDSUM" ]
then
# Checksums match, return cached version
cat /tmp/.Bugview_$BUG_ID.new | sed s/123REPLACEMEWITHUSERSREALNAME456/"$USER_REAL_NAME"/g | sed s/123REPLACEMEWITHUSERSEMAILADDY456/"$USER_EMAIL_ADDRESS"/g | sed s/123REPLACEMEWITHUSERNAME456/"$USERNAME"/g
# Tidy up
rm -f /tmp/.BUGREPORT_DETAILS.upd.$$.new 2> /dev/null
rm -f /tmp/.BUGREPORT_DETAILS.updC.$$ 2> /dev/null
rm -f /tmp/.BUGREPORT_DETAILS.upd.$$ 2> /dev/null
exit
fi
# Checksum does not match

fi
# Either checksums do not match, or there is no cache.








/bin/cat << EOM > /tmp/.Bugview_$BUG_ID.new
<html><head><title>BUGGER - Bug Report $BUG_ID Details</title>

<link rel="StyleSheet"
 href="print.css"
 type="text/css" media="print">
</head>
<body bgcolor="white">
<b><u><center>BUGGER - Bug Report $BUG_ID Details</center></u></b><br>
<br><a href="/BUGGER/Index.shtml?USERNAME=123REPLACEMEWITHUSERNAME456">Home</a><br><hr><br><br>
EOM
# Grab the field values
PROJECT_ID=$( awk -F\, '{print $1}' "/tmp/.BUGREPORT_DETAILS.upd.$$" | sed s/"%3E"/[HTML]/g | sed 's/+/\ /g' | sed s/\"//g | sed s/"%3C"/[HTML]/g )
DATE_LOG=$( awk -F\, '{print $3}' "/tmp/.BUGREPORT_DETAILS.upd.$$" | sed s/"%3E"/[HTML]/g | sed 's/%2F/\//g' | sed s/\"//g | sed s/"%3C"/[HTML]/g )
NAME=$( awk -F\, '{print $5}' "/tmp/.BUGREPORT_DETAILS.upd.$$" | sed s/"%3E"/[HTML]/g | sed 's/+/\ /g' | sed s/\"//g | sed s/"%3C"/[HTML]/g )
DETAILS=$( awk -F\, '{print $6}' "/tmp/.BUGREPORT_DETAILS.upd.$$" | sed 's/%3Cbr%3E/<br>/g' | sed s/"%3E"/[HTML]/g | sed 's/+/\ /g' | sed 's/%2F/\//g' | sed 's/%2C/\,/g' | sed s/\"//g | sed 's/[HTML]br[HTML]/<br>/g' | sed s/"%3C"/[HTML]/g | sed s/%0d/"<br>"/g | sed 's/DOUBLEQUOTES/\"/g' | sed 's/SEMICOLON/\:/g' )
RESOLVED=$( awk -F\, '{print $7}' "/tmp/.BUGREPORT_DETAILS.upd.$$" | sed s/"%3E"/[HTML]/g | sed s/\"//g | sed s/"%3C"/[HTML]/g )
DEVELOPER_NOTES=$( awk -F\, '{print $8}' "/tmp/.BUGREPORT_DETAILS.upd.$$" | sed 's/%3Cbr%3E/<br>/g' | sed s/"%3E"/[HTML]/g | sed 's/+/\ /g' | sed 's/%2F/\//g' | sed 's/%2C/\,/g' | sed s/\"//g | sed s/"%3C"/[HTML]/g | sed s/%0d/"<br>"/g | sed 's/[HTML]br[HTML]/<br>/g' | sed 's/DOUBLEQUOTES/\"/g' | sed 's/SEMICOLON/\:/g' )
DEVELOPER=$( awk -F\, '{print $9}' "/tmp/.BUGREPORT_DETAILS.upd.$$" | sed s/"%3E"/[HTML]/g | sed 's/+/\ /g' | sed 's/%2F/\//g' | sed 's/%2C/\,/g' | sed s/\"//g | sed s/"%3C"/[HTML]/g )



if [ "$PROJECT_ID" == "NORESULTS" ]
then
# Primary Key doesn't exist
/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new
<font color="red">Invalid Bug ID</red><br><br>
<a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a>
</body></html>
EOM
rm -f /tmp/.BUGREPORT_DETAILS.upd.$$ > /dev/null 2> /dev/null
exit
fi

if [ "$PROJECT_ID" == "BADREQUEST" ]
then
# Primary Key doesn't exist
/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new
<font color="red">An Error Occurred</red><br><br>
<a href="/BUGGER/Index.shtml?USERNAME=$USERNAME">Home</a>
</body></html>
EOM
rm -f /tmp/.BUGREPORT_DETAILS.upd.$$ > /dev/null 2> /dev/null
exit
fi


if [ "$RESOLVED" == "" ]
then
STATUS="<font color=orange>Open - Unassigned</font>"
else
if [ "$RESOLVED" == "Y" ]
then
STATUS="<font color=green>Closed - Resolved</font>"
else
if [ "$RESOLVED" == "A" ]
then
STATUS="<font color=Blue>Open - Assigned to $DEVELOPER</font>"
else
if [ "$RESOLVED" == "NI" ]
then
STATUS="<font color=red>Closed - Need more Info</font>"
else
if [ "$RESOLVED" == "T" ]
then

STATUS="<font color=purple>Suspended - Sent for Testing</font>"
else

# The only other input possible is a number. this states that this is a duplicate bug
STATUS="<font color=green>Closed - Duplicate of <a href=http://benscomputer.no-ip.org/BUGGER/View_Bugs.shtml?BUGID=$RESOLVED target=_blank>Bug ID $RESOLVED</a>"
fi
fi
fi
fi
fi



/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new
<a href="Devel_View_bugs.shtml?USERNAME=$USERNAME&BUGID=$BUG_ID">Developer Bug Page</a><br><br>

<table><tbody><tr>
<td><b>Bug Status:</b></td><td><b> $STATUS</b><tr>
<tr><td></td><td></td></tr>
<tr><td><b>Bug ID:</b></td><td>$BUG_ID</td></tr>
<tr><td><b>Project:</b></td><td>
EOM

# Grab the Projects Primary Key so we can link to the changelog

wget -q -O /tmp/.BUGREPORT_DETAILS.upd.$$.PROJDETAILS "http://$DATABASE_SERVER/cgi-bin/Claims_DB_listener.sh?METHOD=4&DBNAME=Bugs&TABLE=Projects&QSTRING=$PROJECT_ID&QCOL=1"

PROJECT_Name=$( awk -F\, '{print $2}' /tmp/.BUGREPORT_DETAILS.upd.$$.PROJDETAILS | sed s/\"//g )

if [ "$PROJECT_Name" == "NORESULTS" ]
then
/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new
<font color="red">Invalid Bug ID</red>
</body></html>
EOM
exit
fi

/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new
<a href="/cgi-bin/Projects/changelog.sh?PROJECT=$PROJECT_ID" target=_blank>$PROJECT_Name</a></td></tr>
<tr><td><b>Date Logged:</b></td><td> $DATE_LOG</td></tr>
<tr><td><b>Logged By:</b></td><td> $NAME</td></tr>
<tr><td></td><td></td></tr>
<tr><td><b>Details</b></td><td>$DETAILS</td></tr>
<tr><td></td><td> </td></tr>
<tr><br><br><td></td><td></td></tr>
<tr><td><b>Developer:</b></td><td>$DEVELOPER</td></tr>
<tr><td><br><br></td><td></td></tr>
<tr><td><b>Developer Notes:</b></td><td>$DEVELOPER_NOTES</td></tr>
<tr><td></td><td> </td></tr>
</tbody></table><br><br><hr><br>
<b>Bug Comments:</b><br><br>
EOM


XXX="0"
STATUSCODE=$( cat /tmp/.BUGREPORT_DETAILS.updC.$$ )
if [ "$STATUSCODE" == "NORESULTS" ]
then
/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new
</body></html>
EOM
rm -f /tmp/.BUGREPORT_DETAILS.updC.$$ > /dev/null 2> /dev/null
XXX="1"

fi

if [ "$STATUSCODE" == "BADREQUEST" ]
then
/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new
Couldn't Retrieve Comments Due to an error
</body></html>
EOM
rm -f /tmp/.BUGREPORT_DETAILS.updC.$$ > /dev/null 2> /dev/null
XXX="1"

fi

if [ "$XXX" != "1" ]
then

while read -r a
do
echo "$a" > /tmp/.BUGREPORT_DETAILS.upd.$$.5
COMMENT_ID=$( awk -F\, '{print $2}' "/tmp/.BUGREPORT_DETAILS.upd.$$.5" | sed s/\"//g | sed s/"%3C"/[HTML]/g | sed s/"%3E"/[HTML]/g | sed s/+/\ /g )
DATE=$( awk -F\, '{print $4}' "/tmp/.BUGREPORT_DETAILS.upd.$$.5" | sed s/\"//g | sed s/"%3C"/[HTML]/g | sed s/"%3E"/[HTML]/g | sed s/+/\ /g )
NAME=$( awk -F\, '{print $5}' "/tmp/.BUGREPORT_DETAILS.upd.$$.5" | sed s/\"//g | sed s/"%3C"/[HTML]/g | sed s/"%3E"/[HTML]/g | sed s/+/\ /g )
COMMENT=$( awk -F\, '{print $3}' "/tmp/.BUGREPORT_DETAILS.upd.$$.5" | sed s/\"//g | sed s/"%3C"/[HTML]/g | sed s/"%3E"/[HTML]/g | sed s/+/\ /g | sed s/%0d/"<br>"/g | sed s/%2C/,/g | sed s/%3A/\:/g | sed s/%3F/?/g | sed s/%25/%/g | sed 's/DOUBLEQUOTES/\"/g' | sed 's/SEMICOLON/\:/g' )

/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new
<br>
<hr><font color="blue" size="+1">
$COMMENT</font>
<hr>
<table width=100%><tbody><tr><td><i><font color="black">$NAME</font></i>


</b></td><td><i><font color="black">$DATE</font></i></b></td><td><a href="abuse_report.shtml?COMMENTID=$COMMENT_ID&BUG=$BUG_ID&USERNAME=$USERNAME" rel="nofollow"><font color="red">Report Abuse</font></td></tr></tbody></table>
<b></b><hr><br>
EOM
done < /tmp/.BUGREPORT_DETAILS.updC.$$
rm -f /tmp/.BUGREPORT_DETAILS.upd.$$.5 > /dev/null 2> /dev/null

fi

# Create Comments form - Only if Bug is unresolved

if [ "$RESOLVED" != "Y" ]
then






/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new
<br>
<hr><div class="noprint">
<br><b>Post a Comment</b>
<br><Br>
<form action="Commentsubmitted.shtml" METHOD=GET>
<table><tbody><tr>
<td>Name:</td><td><Input type="text" Name="Name" VALUE="123REPLACEMEWITHUSERSREALNAME456" Cols="24">
<INPUT TYPE="hidden" NAME="BUG" VALUE="$BUG_ID"><input type="hidden" name="USERNAME" value="123REPLACEMEWITHUSERNAME456"></td></tr>
<tr>
<td>
Email Address: </td><td><input type="text" NAME="Email" value="123REPLACEMEWITHUSERSEMAILADDY456"> - Visible only to Developers</td>
</tr>
<tr>
<td>Comment:</td><td><TEXTAREA name="Comment" Cols="24" Rows="8"></textarea></td></tr>
EOM



CAPTCHA_ENABLED=$(awk -F\, '{print $4}' /tmp/BUGGER.bugview.comment.captcha.$$ | sed s/\"//g )



if [ "$CAPTCHA_ENABLED" == "Y" ]
then
CAPTCHA_QUESTION=$(awk -F\, '{print $2}' /tmp/BUGGER.bugview.comment.captcha.$$ | sed s/\"//g )

/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new
<tr><td>$CAPTCHA_QUESTION</td><td><INPUT TYPE="text" NAME="Puzzle"></td></tr>
EOM
else

/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new
</td><td></td></tr>
EOM

fi


/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new

<tr><td></td><td><center><Input type="submit" onclick="this.disabled=1; this.form.submit()" value="Submit" ></center></td></tr>
</tbody></table>
</form>
</div>

EOM
fi

./BUGGER_generate_footer.sh >> /tmp/.Bugview_$BUG_ID.new
/bin/cat << EOM >> /tmp/.Bugview_$BUG_ID.new

</body></html>
EOM

# All we've done is cache the file. Return it to the user 

cat /tmp/.Bugview_$BUG_ID.new | sed s/123REPLACEMEWITHUSERSREALNAME456/"$USER_REAL_NAME"/g | sed s/123REPLACEMEWITHUSERSEMAILADDY456/"$USER_EMAIL_ADDRESS"/g | sed s/123REPLACEMEWITHUSERNAME456/"$USERNAME"/g
# Store the checksum for lateruse

cat /tmp/.BUGREPORT_DETAILS.upd.$$.new > /tmp/.Bugview_$BUG_ID.new.sum


rm -f /tmp/.BUGREPORT_DETAILS.updC.$$ > /dev/null 2> /dev/null
exit